/**
 * Modulo calculation function for calculating an index position in a circular list/array,
 * useful for implementing carousels and other circular lists.
 *
 * If argument `a` is less than or greater than the given `n` length the function returns a new index
 * reflects "wrapping around" a circle with `n` slots.
 *
 * @param a current index
 * @param n total count of items in the carousel (e.g. array length)
 * @returns next index value
 */
declare const mod: (a: number, n: number) => number;

declare function unixTimeToDate(unixTimestampSeconds: number): Date;

/**
 * Error helper to return the error message of an `unknown` error.
 * Handles the case where the error is not specifically an instance of `Error`.
 *
 * @see https://kentcdodds.com/blog/get-a-catch-block-error-message-with-typescript
 */
declare function getErrorMessage(error: unknown): string;

/**
 * Type guard that evaluates whether its input is an array of strings.
 * Returns `true` for an empty array.
 */
declare function isStringArray(value: unknown): value is string[];

declare function isNonNullable<T>(input: unknown): input is NonNullable<T>;
declare function isNullish(input: unknown): input is undefined | null;
declare function isNull(input: unknown): input is null;
declare function isUndefined(input: unknown): input is undefined;

/**
 * Type guard for `Record<string, unknown>`.
 */
declare function isRecord(input: unknown): input is Record<string, unknown>;

export { getErrorMessage, isNonNullable, isNull, isNullish, isRecord, isStringArray, isUndefined, mod, unixTimeToDate };
